SWDEV-240807 - Fix header file

Remove class useage from header file

Change-Id: Ibe1a59241f000cc162dd865484c313e56c4db95f


[ROCm/clr commit: 223c0364f8]
This commit is contained in:
Christophe Paquot
2021-07-20 08:04:04 -07:00
committed by Christophe Paquot
parent d407cc46ee
commit 9488cd1194
3 changed files with 15 additions and 15 deletions
+2 -2
View File
@@ -302,7 +302,7 @@ hipError_t hipStreamBeginCapture(hipStream_t stream, hipStreamCaptureMode mode)
if (stream == nullptr || s->GetCaptureStatus() == hipStreamCaptureStatusActive) {
HIP_RETURN(hipErrorInvalidValue);
}
s->SetCaptureGraph(new hipGraph());
s->SetCaptureGraph(new ihipGraph());
s->SetCaptureMode(mode);
s->SetOriginStream();
g_captureStreams.push_back(stream);
@@ -339,7 +339,7 @@ hipError_t hipStreamEndCapture(hipStream_t stream, hipGraph_t* pGraph) {
hipError_t hipGraphCreate(hipGraph_t* pGraph, unsigned int flags) {
HIP_INIT_API(hipGraphCreate, pGraph, flags);
*pGraph = new hipGraph();
*pGraph = new ihipGraph();
HIP_RETURN(hipSuccess);
}